SET default_transaction_read_only = off;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;

ALTER TABLE IF EXISTS adm.camera_log ADD COLUMN IF NOT EXISTS score double precision NOT NULL DEFAULT 0;

ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS detector_accuracy numeric(2,0) NOT NULL DEFAULT 1;

ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS detector_type character varying(255) COLLATE pg_catalog."default" NOT NULL DEFAULT 'horizontal';

ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS detector_unique numeric(1,0) NOT NULL DEFAULT 0;

ALTER TABLE IF EXISTS adm.camera DROP CONSTRAINT IF EXISTS camera_ck8;
ALTER TABLE IF EXISTS adm.camera ADD CONSTRAINT camera_ck8 CHECK (detector_unique = ANY (ARRAY[0::numeric, 1::numeric]));

ALTER TABLE IF EXISTS adm.persons DROP CONSTRAINT IF EXISTS persons_ck;
ALTER TABLE IF EXISTS adm.persons ADD CONSTRAINT persons_ck CHECK (status = ANY (ARRAY[0::numeric, 1::numeric, 3::numeric, 4::numeric]));

ALTER TABLE IF EXISTS adm.camera ALTER COLUMN hls SET NOT NULL;
ALTER TABLE IF EXISTS adm.camera ALTER COLUMN pretrack SET NOT NULL;
ALTER TABLE IF EXISTS adm.camera DROP CONSTRAINT IF EXISTS camera_ck9;
ALTER TABLE IF EXISTS adm.camera ADD CONSTRAINT camera_ck9 CHECK (hls = ANY (ARRAY[0::numeric, 1::numeric]));
ALTER TABLE IF EXISTS adm.camera DROP CONSTRAINT IF EXISTS camera_ck10;
ALTER TABLE IF EXISTS adm.camera ADD CONSTRAINT camera_ck10 CHECK (pretrack = ANY (ARRAY[0::numeric, 1::numeric]));
ALTER TABLE IF EXISTS adm.camera_log DROP CONSTRAINT IF EXISTS camera_log_ck1;
ALTER TABLE IF EXISTS adm.camera_log ADD CONSTRAINT camera_log_ck1 CHECK (status = ANY (ARRAY[0::numeric, 1::numeric, 2::numeric, 3::numeric, 4::numeric]));

ALTER TABLE IF EXISTS adm.persons ADD COLUMN IF NOT EXISTS "timestamp" date;

ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS detector_unique numeric(1,0) NOT NULL DEFAULT 0;
ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS way_status numeric(1,0) NOT NULL DEFAULT 0;
ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS address_second text COLLATE pg_catalog."default";
ALTER TABLE IF EXISTS adm.persons ADD COLUMN IF NOT EXISTS obj_id numeric(9,0);
ALTER TABLE IF EXISTS adm.persons DROP CONSTRAINT IF EXISTS persons_fk1;
UPDATE adm.persons SET obj_id=NULL WHERE obj_id IS NOT NULL AND obj_id NOT IN (SELECT t7.id_gr_ob FROM adm.asu_tree_gr_ob t7);
ALTER TABLE IF EXISTS adm.persons
    ADD CONSTRAINT persons_fk1 FOREIGN KEY (obj_id)
    REFERENCES adm.asu_tree_gr_ob (id_gr_ob) MATCH SIMPLE
    ON UPDATE SET NULL
    ON DELETE SET NULL;

-- 27.10.22
CREATE SEQUENCE IF NOT EXISTS adm.vms_servers_seq
    CYCLE
    INCREMENT 1
    START 1
    MINVALUE 1
    MAXVALUE 999999
    CACHE 1;

ALTER SEQUENCE adm.vms_servers_seq
    OWNER TO postgres;

COMMENT ON SEQUENCE adm.vms_servers_seq
    IS 'Идентификатор vms_servers';

GRANT ALL ON SEQUENCE adm.vms_servers_seq TO postgres;
GRANT SELECT, UPDATE ON SEQUENCE adm.vms_servers_seq TO user1;

CREATE SEQUENCE IF NOT EXISTS adm.vms_vendors_seq
    CYCLE
    INCREMENT 1
    START 1
    MINVALUE 1
    MAXVALUE 999999
    CACHE 1;

ALTER SEQUENCE adm.vms_vendors_seq
    OWNER TO postgres;

COMMENT ON SEQUENCE adm.vms_vendors_seq
    IS 'Идентификатор записи в таблице vms_vendors';

GRANT ALL ON SEQUENCE adm.vms_vendors_seq TO postgres;

GRANT SELECT, UPDATE ON SEQUENCE adm.vms_vendors_seq TO user1;

CREATE TABLE IF NOT EXISTS adm.vms_vendors
(
    id numeric(11,0) NOT NULL DEFAULT nextval('adm.vms_vendors_seq'::regclass),
    vendor_name character varying(255) COLLATE pg_catalog."default" NOT NULL,
    CONSTRAINT vms_vendors_pk PRIMARY KEY (id),
    CONSTRAINT vms_vendors_uk UNIQUE (vendor_name)
)

TABLESPACE pg_default;

ALTER TABLE IF EXISTS adm.vms_vendors
    OWNER to postgres;

REVOKE ALL ON TABLE adm.vms_vendors FROM user1;
GRANT ALL ON TABLE adm.vms_vendors TO postgres;
GRANT UPDATE, INSERT, SELECT ON TABLE adm.vms_vendors TO user1;

COMMENT ON TABLE adm.vms_vendors
    IS 'Перечень вендоров для видеосерверов';

COMMENT ON COLUMN adm.vms_vendors.vendor_name
    IS 'Название вендора';

INSERT INTO adm.vms_vendors(id, vendor_name) VALUES (1, 'TRASSIR') ON CONFLICT(id) DO NOTHING;
INSERT INTO adm.vms_vendors(id, vendor_name) VALUES (0, 'SentinelVMS') ON CONFLICT(id) DO NOTHING;
SELECT pg_catalog.setval('adm.vms_vendors_seq', 1, true);
CREATE TABLE IF NOT EXISTS adm.vms_servers
(
    id numeric(11,0) NOT NULL DEFAULT nextval('adm.vms_servers_seq'::regclass),
    vms_name character varying(255) COLLATE pg_catalog."default" NOT NULL,
    vms_address text COLLATE pg_catalog."default" NOT NULL,
    vms_port integer NOT NULL,
    vms_login character varying(255) COLLATE pg_catalog."default" NOT NULL,
    vms_password character varying(255) COLLATE pg_catalog."default" NOT NULL,
    vms_timezone character varying(255) COLLATE pg_catalog."default" NOT NULL,
    vms_params text COLLATE pg_catalog."default",
    vms_vendor_id numeric(11,0) NOT NULL,
    CONSTRAINT vms_servers_pk PRIMARY KEY (id),
    CONSTRAINT vms_servers_uk UNIQUE (vms_name),
    CONSTRAINT vms_servers_vms_vendor_id_fk FOREIGN KEY (vms_vendor_id)
        REFERENCES adm.vms_vendors (id) MATCH SIMPLE
        ON UPDATE CASCADE
        ON DELETE CASCADE
)

TABLESPACE pg_default;

ALTER TABLE IF EXISTS adm.vms_servers
    OWNER to postgres;

REVOKE ALL ON TABLE adm.vms_servers FROM user1;

GRANT ALL ON TABLE adm.vms_servers TO postgres;

GRANT DELETE, UPDATE, INSERT, SELECT ON TABLE adm.vms_servers TO user1;

ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS vms_id numeric(11,0);

ALTER TABLE IF EXISTS adm.camera ADD COLUMN IF NOT EXISTS external_id character varying(512) COLLATE pg_catalog."default";

ALTER TABLE IF EXISTS adm.camera DROP CONSTRAINT IF EXISTS camera_servers_fnv_id_fk;
ALTER TABLE IF EXISTS adm.camera
    ADD CONSTRAINT camera_servers_fnv_id_fk FOREIGN KEY (server_id)
    REFERENCES adm.servers_fnv (id) MATCH SIMPLE
    ON UPDATE CASCADE
    ON DELETE SET NULL;

ALTER TABLE IF EXISTS adm.camera DROP CONSTRAINT IF EXISTS camera_vms_servers_id_fk;
ALTER TABLE IF EXISTS adm.camera
    ADD CONSTRAINT camera_vms_servers_id_fk FOREIGN KEY (vms_id)
    REFERENCES adm.vms_servers (id) MATCH SIMPLE
    ON UPDATE CASCADE
    ON DELETE SET NULL;

DELETE FROM adm.settings_fnv WHERE id_parameter IN(10, 11);
SELECT pg_catalog.setval('adm.settings_fnv_seq', 9, true);

ALTER TABLE IF EXISTS adm.camera DROP COLUMN IF EXISTS detector_temperature;
ALTER TABLE IF EXISTS adm.camera_log DROP COLUMN IF EXISTS temperature;

INSERT INTO adm.adm_action_roles(id_action, name_action, full_name_action) VALUES (16, 'ACCESS_VMS_LIST_FNV', 'Чтение списка VMS. Доступ к вкладке видеосерера') ON CONFLICT (id_action) DO NOTHING;
INSERT INTO adm.adm_action_roles(id_action, name_action, full_name_action) VALUES (17, 'ACCESS_VMS_LIST_UPD_FNV', 'Редактирование параметров видеосервера') ON CONFLICT (id_action) DO NOTHING;
INSERT INTO adm.adm_action_roles(id_action, name_action, full_name_action) VALUES (18, 'ACCESS_VMS_LIST_DEL_FNV', 'Удаление записей из списка видеосерверов') ON CONFLICT (id_action) DO NOTHING;


INSERT INTO adm.roles_actions(id_role, id_action) VALUES (0, 16) ON CONFLICT (id_role, id_action) DO NOTHING;
INSERT INTO adm.roles_actions(id_role, id_action) VALUES (0, 17) ON CONFLICT (id_role, id_action) DO NOTHING;
INSERT INTO adm.roles_actions(id_role, id_action) VALUES (0, 18) ON CONFLICT (id_role, id_action) DO NOTHING;

-- 15.07.24

DELETE
FROM adm.adm_action_roles;

DELETE
FROM adm.roles_actions;

-- 16.07.24
INSERT INTO adm.adm_action_roles (id_action, name_action, full_name_action)
VALUES (1, 'ACCESS_VIDEO_ARCHIVE_DET_FNV', 'Доступ к архивному видео, вкладка детектирование'),
       (2, 'ACCESS_LICENSE_FNV', 'Доступ к управлению лицензиями'),
       (3, 'ACCESS_VIEWS_LICENSE_FNV', 'Доступ к отображению вкладки лицензии'),
       (4, 'ACCESS_EVENTS_FNV', 'Получения записей событий'),
       (5, 'ACCESS_VIEWS_EVENTS_DETECTION_FNV', 'Доступ к отображению вкладки детектирования'),
       (6, 'ACCESS_VIEWS_EVENTS_ARCHIVE_FNV', 'Доступ к отображению вкладки архива'),
       (7, 'ACCESS_VIEWS_VMS_FNV', 'Доступ к отображению вкладки видео серверов'),
       (8, 'ACCESS_VMS_DELETE_FNV', 'Доступ к видео серверам. Удаление записей'),
       (9, 'ACCESS_VMS_UPDATE_FNV', 'Доступ к видео серверам. Редактирование записей'),
       (10, 'ACCESS_VMS_CREATE_FNV', 'Доступ к видео серверам. Создание записей'),
       (11, 'ACCESS_VMS_READ_FNV', 'Доступ к видео серверам. Получение записей'),
       (12, 'ACCESS_SERVERS_CREATE_FNV', 'Доступ к серверам аналитики. Создание записей'),
       (13, 'ACCESS_SERVERS_DELETE_FNV', 'Доступ к серверам аналитики. Удаление записей'),
       (14, 'ACCESS_SERVERS_UPDATE_FNV', 'Доступ к серверам аналитики. Редактирование записей'),
       (15, 'ACCESS_SERVERS_READ_FNV', 'Доступ к серверам аналитики. Получение записей'),
       (16, 'ACCESS_VIEWS_SERVER_FNV', 'Доступ к к отображению вкладки серверов'),
       (17, 'ACCESS_VIEW_INTEGRATIONS_FNV', 'Доступ к к отображению вкладки интергаций'),
       (18, 'ACCESS_INTEGRATIONS_CREATE_FNV', 'Доступ к к отображению вкладки интергаций'),
       (19, 'ACCESS_INTEGRATIONS_UPDATE_FNV', 'Доступ к к отображению вкладки интергаций'),
       (20, 'ACCESS_INTEGRATIONS_DELETE_FNV', 'Доступ к к отображению вкладки интергаций'),
       (21, 'ACCESS_INTEGRATIONS_READ_FNV', 'Доступ к к отображению вкладки интергаций'),
       (22, 'ACCESS_SYSTEM_INTEGRATIONS_FNV', 'Доступ к функциям интеграции со сторонними устройствами'),
       (23, 'ACCESS_EXTERNAL_TABLES_FNV', 'Доступ к функциям интеграции со сторонними устройствами на уровне БД'),
       (24, 'ACCESS_VIEW_PERSONS_FNV', 'Доступ к вкладке картотеки'),
       (25, 'ACCESS_PERSONS_CREATE_FNV', 'Доступ к функции создания картотеки'),
       (26, 'ACCESS_PERSONS_UPDATE_FNV', 'Доступ к функции изменения картотеки'),
       (27, 'ACCESS_PERSONS_DELETE_FNV', 'Доступ к функции удаления картотеки'),
       (28, 'ACCESS_PERSONS_READ_FNV', 'Доступ к функции чтения картотеки'),
       (29, 'ACCESS_ZONES_CREATE_FNV', 'Доступ к функции создания зон'),
       (30, 'ACCESS_ZONES_UPDATE_FNV', 'Доступ к функции изменения зон'),
       (31, 'ACCESS_ZONES_DELETE_FNV', 'Доступ к функции удаления зон'),
       (32, 'ACCESS_ZONES_READ_FNV', 'Доступ к функции чтения зон'),
       (33, 'ACCESS_CAMERAS_SWITCH_FNV', 'Доступ к камерам. Вкл/Выкл камер'),
       (34, 'ACCESS_CAMERAS_UPDATE_FNV', 'Доступ к камерам. Редактирование записей'),
       (35, 'ACCESS_CAMERAS_READ_FNV', 'Доступ к камерам. Получение записей'),
       (36, 'ACCESS_CAMERAS_DELETE_FNV', 'Доступ к камерам. Удаление записей'),
       (37, 'ACCESS_CAMERAS_CREATE_FNV', 'Доступ к камерам. Создание записей'),
       (38, 'ACCESS_VIEWS_CAMERA_FNV', 'Доступ к отображению вкладки камер'),
       (39, 'ACCESS_AUTH_FNV', 'Доступ к управлению пользователями и правами доступа'),
       (40, 'ACCESS_SYSTEM_FNV', 'Доступ к компонентам системы сервера'),
       (41, 'ACCESS_VIEWS_USERS_FNV', 'Доступ к отображению вкладки пользователей'),
       (42, 'ACCESS_VIEWS_ROLES_FNV', 'Доступ к отображению вкладки ролей'),
       (43, 'ACCESS_GL_FNV', 'Доступ к серверу. Для рутового доступа'),
       (44, 'ACCESS_VERIFICATION_FNV', 'Доступ к функциям верификации'),
       (45, 'ACCESS_FILES_FNV', 'Доступ к функциям поучения файлов с сервера'),
       (46, 'ACCESS_VIEWS_STATISTICS_FNV', 'Доступ к отображению вкладки статистики'),
       (47, 'ACCESS_VIEWS_FIND_FACE_FNV', 'Доступ к отображению вкладки поиска лиц по файлу'),
       (48, 'ACCESS_VIEWS_OBJECTS_FNV', 'Доступ к отображению вкладки поиска лиц по файлу'),
       (49, 'ACCESS_OBJECTS_READ_FNV', 'Доступ к функции чтения объектов'),
       (50, 'ACCESS_OBJECTS_CREATE_FNV', 'Доступ к функции чтения объектов'),
       (51, 'ACCESS_OBJECTS_UPDATE_FNV', 'Доступ к функции записи объектов'),
       (52, 'ACCESS_OBJECTS_DELETE_FNV', 'Доступ к функции удаления объектов'),
       (53, 'ACCESS_SYSTEM_POWER_FNV', 'Доступ к функции управления питанием сервера'),
       (54, 'ACCESS_VIDEO_ARCHIVE_ARCH_FNV', 'Доступ к архивному видео, вкладка архив'),
       (55, 'ACCESS_VIEWS_PERSONS_CREATE_DET_FNV', 'Доступ к отображению вкладки создания персоны в детектировании'),
       (56, 'ACCESS_VIEWS_PERSONS_CREATE_ARCH_FNV', 'Доступ к отображению вкладки создания персоны в архиве'),
       (57, 'ACCESS_VIEWS_PERSONS_CREATE_CARD_FNV', 'Доступ к отображению вкладки создания персоны в картотеке')
ON CONFLICT DO NOTHING;

INSERT INTO adm.roles_actions(id_role, id_action)
VALUES (0, 1),
       (0, 2),
       (0, 3),
       (0, 4),
       (0, 5),
       (0, 6),
       (0, 7),
       (0, 8),
       (0, 9),
       (0, 10),
       (0, 11),
       (0, 12),
       (0, 13),
       (0, 14),
       (0, 15),
       (0, 16),
       (0, 17),
       (0, 18),
       (0, 19),
       (0, 20),
       (0, 21),
       (0, 22),
       (0, 23),
       (0, 24),
       (0, 25),
       (0, 26),
       (0, 27),
       (0, 28),
       (0, 29),
       (0, 30),
       (0, 31),
       (0, 32),
       (0, 33),
       (0, 34),
       (0, 35),
       (0, 36),
       (0, 37),
       (0, 38),
       (0, 39),
       (0, 40),
       (0, 41),
       (0, 42),
       (0, 43),
       (0, 44),
       (0, 45),
       (0, 46),
       (0, 47),
       (0, 48),
       (0, 49),
       (0, 50),
       (0, 51),
       (0, 52),
       (0, 53),
       (0, 54),
       (0, 55),
       (0, 56),
       (0, 57)
ON CONFLICT DO NOTHING;

-- 28.08.2024
ALTER TABLE IF EXISTS adm.vms_servers ADD COLUMN vms_live_stream_port integer;
ALTER TABLE IF EXISTS adm.camera ADD COLUMN connect_type numeric(1,0) DEFAULT 0 NOT NULL;
ALTER TABLE IF EXISTS adm.camera ADD CONSTRAINT camera_ck11 CHECK ((connect_type = ANY (ARRAY[(0)::numeric, (1)::numeric])));
